@@ -196,6 +196,7 @@ class GithubConnector(ToucanConnector):
         retrieved_pages=0,
         retries=0,
         retry_limit=4,
+        latest_retrieved_object=None,
     ) -> List[dict]:
         """
         Extracts pages of either members or pull requests
@@ -209,6 +210,9 @@ class GithubConnector(ToucanConnector):
         :param: retrieved_pages int number of pages retrieved
         :param: retries the number of retries done when we got an error
         :param: retry_limit the max number of retries the connector can do
+        :param: latest_retrieved_object str of either the latest user name or pull request name retrieved
+        in a previous extraction. This will allow to call get_pages to extract only new object (users or pr)
+        since the last extraction
         :return: list of extracted data
         """
         if variables is None:
@@ -226,15 +230,31 @@ class GithubConnector(ToucanConnector):
                 extraction_funcs_pages_2[dataset](get_organization(get_data(data)))
             )
             page_info = get_page_info(extracted_data)
+            formatted_data = format_functions[dataset](extracted_data, name)
 
-            if dataset == 'pull requests':
-                data_list.extend(format_functions[dataset](extracted_data, name))
+            # Check if the extraction script can see a previously extracted object (e.g PR)
+            # in current page
+
+            if latest_retrieved_object and dataset == GithubDataSet('pull requests'):
+                # check if latest_retrieved_object is in current page
+
+                try:
+                    index = [pr['PR Name'] for pr in formatted_data].index(latest_retrieved_object)
+                    formatted_data = formatted_data[:index]
+                    data_list.extend(formatted_data)
+                    return data_list
+                except ValueError:
+                    pass
+
+            if dataset == GithubDataSet('pull requests'):
+                data_list.extend(formatted_data)
             else:
-                data_list.append(format_functions[dataset](extracted_data, name))
+                data_list.append(formatted_data)
 
             if has_next_page(page_info) and retrieved_pages < page_limit:
                 retrieved_pages += 1
                 variables['cursor'] = get_cursor(page_info)
+
                 await self.get_pages(
                     name=name,
                     client=client,
@@ -244,6 +264,7 @@ class GithubConnector(ToucanConnector):
                     data_list=data_list,
                     retrieved_pages=retrieved_pages,
                     page_limit=page_limit,
+                    latest_retrieved_object=latest_retrieved_object,
                 )
 
         except GithubError:
@@ -261,6 +282,7 @@ class GithubConnector(ToucanConnector):
                     retrieved_pages=retrieved_pages,
                     retries=retries,
                     page_limit=page_limit,
+                    latest_retrieved_object=latest_retrieved_object,
                 )
             else:
                 raise GithubError('Max number of retries reached, aborting connection')
@@ -277,6 +299,7 @@ class GithubConnector(ToucanConnector):
         client: GraphqlClient,
         page_limit: int,
         names_limit=None,
+        latest_retrieved_object=None,
     ) -> pd.DataFrame:
         """
          Builds the coroutines ran by _retrieve_data
@@ -286,6 +309,7 @@ class GithubConnector(ToucanConnector):
         :param client a GraphqlClient that will make the requests to Github's API
         :param page_limit max number of pages to be retrieved by get_pages
         :param names_limit number max of "names" (teams/repos) to extract the data from
+        :param latest_retrieved_object a dict with object as key and entity as value e. g {'repo': 'plop', 'pr: stuff'}
         :return: a Pandas DataFrame of pull requests or team memberships
         """
         logging.getLogger(__name__).info(f'Starting fetch for {dataset}')
@@ -297,6 +321,9 @@ class GithubConnector(ToucanConnector):
                 dataset=dataset,
                 organization=organization,
                 page_limit=page_limit,
+                latest_retrieved_object=latest_retrieved_object[name]
+                if latest_retrieved_object
+                else None,
             )
             for name in names[:names_limit]
         ]
